@@ -16,11 +16,32 @@
 
 from typing import TypeVar
 
-KT = TypeVar("KT") # The Key Type of the Dataset (mostly int for Primary Keys, but strings are also possible)
-DT = TypeVar("DT") # The Type of the data point
-VT = TypeVar("VT") # The Type of the vector
-RT = TypeVar("RT") # The Type of the representation of the data point
-LT = TypeVar("LT") # The Type of the labels
-CT = TypeVar("CT") # The Type of the context
-LVT = TypeVar("LVT") # The Type of the encoded label vector
+
+KT = TypeVar("KT") 
+"""The Key Type of the Dataset (mostly int for Primary Keys, but strings are also possible)"""
+
+DT = TypeVar("DT")
+"""The Type of the data point """
+
+VT = TypeVar("VT")
+"""The Type of the vector"""
+RT = TypeVar("RT")
+"""The Type of the representation of the data point"""
+
+LT = TypeVar("LT")
+"""The Type of the labels"""
+CT = TypeVar("CT")
+"""The Type of the context"""
+
+LVT = TypeVar("LVT")
+"""The Type of the encoded label vector"""
+
 PVT = TypeVar("PVT")
+"""The Type of the encoded probability vector"""
+
+LMT = TypeVar("LMT")
+"""The Type of the label matrix"""
+
+PMT = TypeVar("PMT")
+"""The Type of the encoded probability matrix"""
+
